==> dwarfg_install_1.0.3.tgz: dwarfg_install/appdir/web/gui/src/Bundles/Sg/DatatablesBundle/Datatable/Column/DwarfgBooleanColumn.php <==
<?php

namespace  App\Bundles\Sg\DatatablesBundle\Datatable\Column;

use Sg\DatatablesBundle\Datatable\Column\AbstractColumn;
use Sg\DatatablesBundle\Datatable\Column\EditableTrait;
use Sg\DatatablesBundle\Datatable\Column\FilterableTrait;
use Sg\DatatablesBundle\Datatable\Editable\EditableInterface;
use Sg\DatatablesBundle\Datatable\Filter\SelectFilter;
use Sg\DatatablesBundle\Datatable\Helper;
use Symfony\Component\OptionsResolver\Options;
use Symfony\Component\OptionsResolver\OptionsResolver;

class DwarfgBooleanColumn extends AbstractColumn
{
    use EditableTrait;

    use FilterableTrait;

    /**
     * @internal
     */
    public const RENDER_TRUE_VALUE = 'true';

    /**
     * @internal
     */
    public const RENDER_FALSE_VALUE = 'false';

    /**
     * The icon for a value that is true.
     * Default: null.
     *
     * @var string|null
     */
    protected $trueIcon;

    /**
     * The icon for a value that is false.
     * Default: null.
     *
     * @var string|null
     */
    protected $falseIcon;

    /**
     * The label for a value that is true.
     * Default: null.
     *
     * @var string|null
     */
    protected $trueLabel;

    /**
     * The label for a value that is false.
     * Default: null.
     *
     * @var string|null
     */
    protected $falseLabel;

    //-------------------------------------------------
    // ColumnInterface
    //-------------------------------------------------

    /**
     * {@inheritdoc}
     */
    public function renderSingleField(array &$row)
    {
        $path = Helper::getDataPropertyPath($this->data);

        if ($this->accessor->isReadable($row, $path)) {
            if (true === $this->isEditableContentRequired($row)) {
                $content = $this->renderTemplate($this->accessor->getValue($row, $path), $row[$this->editable->getPk()]);
            } else {
                $content = $this->renderTemplate($this->accessor->getValue($row, $path));
            }

            $this->accessor->setValue($row, $path, $content);
        }

        return $this;
    }

    /**
     * {@inheritdoc}
     */
    public function renderToMany(array &$row)
    {
        $value = null;
        $path = Helper::getDataPropertyPath($this->data, $value);

        if ($this->accessor->isReadable($row, $path)) {
            $entries = $this->accessor->getValue($row, $path);

            if (\count($entries) > 0) {
                foreach ($entries as $key => $entry) {
                    $currentPath = $path.'['.$key.']'.$value;
                    $currentObjectPath = Helper::getPropertyPathObjectNotation($path, $key, $value);

                    if (true === $this->isEditableContentRequired($row)) {
                        $content = $this->renderTemplate(
                            $this->accessor->getValue($row, $currentPath),
                            $row[$this->editable->getPk()],
                            $currentObjectPath
                        );
                    } else {
                        $content = $this->renderTemplate($this->accessor->getValue($row, $currentPath));
                    }

                    $this->accessor->setValue($row, $currentPath, $content);
                }
            }
            // no placeholder - leave this blank
        }

        return $this;
    }

    /**
     * {@inheritdoc}
     */
    public function getCellContentTemplate()
    {
        return '@SgDatatables/render/boolean.html.twig';
    }

    /**
     * {@inheritdoc}
     */
    public function renderPostCreateDatatableJsContent()
    {
        if ($this->editable instanceof EditableInterface) {
            return $this->twig->render(
                '@SgDatatables/column/column_post_create_dt.js.twig',
                [
                    'column_class_editable_selector' => $this->getColumnClassEditableSelector(),
                    'editable_options' => $this->editable,
                    'entity_class_name' => $this->getEntityClassName(),
                    'column_dql' => $this->dql,
                    'original_type_of_field' => $this->getOriginalTypeOfField(),
                ]
            );
        }

        return null;
    }

    //-------------------------------------------------
    // Options
    //-------------------------------------------------

    /**
     * @return $this
     */
    public function configureOptions(OptionsResolver $resolver)
    {
        parent::configureOptions($resolver);

        $resolver->setDefaults(
            [
                'filter' => [
                    SelectFilter::class,
                    [
                        'search_type' => 'eq',
                        'select_options' => ['' => 'Any', '1' => 'Yes', '0' => 'No'],
                    ],
                ],
                'true_icon' => null,
                'false_icon' => null,
                'true_label' => null,
                'false_label' => null,
                'editable' => null,
            ]
        );

        $resolver->setAllowedTypes('filter', 'array');
        $resolver->setAllowedTypes('true_icon', ['null', 'string']);
        $resolver->setAllowedTypes('false_icon', ['null', 'string']);
        $resolver->setAllowedTypes('true_label', ['null', 'string']);
        $resolver->setAllowedTypes('false_label', ['null', 'string']);
        $resolver->setAllowedTypes('editable', ['null', 'array']);

        $resolver->setNormalizer('true_label', function (Options $options, $value) {
            if (null === $options['true_icon'] && null === $value) {
                $value = self::RENDER_TRUE_VALUE;
            }

            return $value;
        });

        $resolver->setNormalizer('false_label', function (Options $options, $value) {
            if (null === $options['false_icon'] && null === $value) {
                $value = self::RENDER_FALSE_VALUE;
            }

            return $value;
        });

        return $this;
    }

    //-------------------------------------------------
    // Getters && Setters
    //-------------------------------------------------

    /**
     * @return string|null
     */
    public function getTrueIcon()
    {
        return $this->trueIcon;
    }

    /**
     * @param string|null $trueIcon
     *
     * @return $this
     */
    public function setTrueIcon($trueIcon)
    {
        $this->trueIcon = $trueIcon;

        return $this;
    }

    /**
     * @return string|null
     */
    public function getFalseIcon()
    {
        return $this->falseIcon;
    }

    /**
     * @param string|null $falseIcon
     *
     * @return $this
     */
    public function setFalseIcon($falseIcon)
    {
        $this->falseIcon = $falseIcon;

        return $this;
    }

    /**
     * @return string|null
     */
    public function getTrueLabel()
    {
        return $this->trueLabel;
    }

    /**
     * @param string|null $trueLabel
     *
     * @return $this
     */
    public function setTrueLabel($trueLabel)
    {
        $this->trueLabel = $trueLabel;

        return $this;
    }

    /**
     * @return string|null
     */
    public function getFalseLabel()
    {
        return $this->falseLabel;
    }

    /**
     * @param string|null $falseLabel
     *
     * @return $this
     */
    public function setFalseLabel($falseLabel)
    {
        $this->falseLabel = $falseLabel;

        return $this;
    }

    //-------------------------------------------------
    // Helper
    //-------------------------------------------------

    /**
     * Render template.
     *
     * @param string|null $data
     * @param string|null $pk
     * @param string|null $path
     *
     * @return mixed|string
     */
    private function renderTemplate($data, $pk = null, $path = null)
    {
        /*var_dump($this->trueLabel,$data);
        var_dump(\in_array($data, [0, 1, '0', '1'], true));
        var_dump($this->isCustomDql() && \in_array($data, [0, 1, '0', '1'], true) ? (bool) $data : $data);
       */ $renderVars = [
            'data' => $this->isCustomDql() && \in_array($data, [0, 1, '0', '1'], true) ? (bool) $data : (bool) $data,
            'default_content' => $this->getDefaultContent(),
            'true_label' => $this->trueLabel,
            'true_icon' => $this->trueIcon,
            'false_label' => $this->falseLabel,
            'false_icon' => $this->falseIcon,
        ];

        // editable vars
        if (null !== $pk) {
            $renderVars = array_merge($renderVars, [
                'column_class_editable_selector' => $this->getColumnClassEditableSelector(),
                'pk' => $pk,
                'path' => $path,
                'empty_text' => $this->editable->getEmptyText(),
            ]);
        }

        return $this->twig->render(
            $this->getCellContentTemplate(),
            $renderVars
        );
    }
}

==> dwarfg_install_1.9.0.tgz: dwarfg_install/appdir/web/gui/src/Bundles/Sg/DatatablesBundle/Datatable/Column/DwarfgBooleanColumn.php <==
<?php

namespace  App\Bundles\Sg\DatatablesBundle\Datatable\Column;

use Sg\DatatablesBundle\Datatable\Column\AbstractColumn;
use Sg\DatatablesBundle\Datatable\Column\ColumnInterface;
use Sg\DatatablesBundle\Datatable\Column\EditableTrait;
use Sg\DatatablesBundle\Datatable\Column\FilterableTrait;
use Sg\DatatablesBundle\Datatable\Editable\EditableInterface;
use Sg\DatatablesBundle\Datatable\Filter\SelectFilter;
use Sg\DatatablesBundle\Datatable\Helper;
use Symfony\Component\OptionsResolver\Options;
use Symfony\Component\OptionsResolver\OptionsResolver;

class DwarfgBooleanColumn extends AbstractColumn
{
    use EditableTrait;

    use FilterableTrait;

    /**
     * @internal
     */
    public const RENDER_TRUE_VALUE = 'true';

    /**
     * @internal
     */
    public const RENDER_FALSE_VALUE = 'false';

    /**
     * The icon for a value that is true.
     * Default: null.
     *
     * @var string|null
     */
    protected ?string $trueIcon;

    /**
     * The icon for a value that is false.
     * Default: null.
     *
     * @var string|null
     */
    protected ?string $falseIcon;

    /**
     * The label for a value that is true.
     * Default: null.
     *
     * @var string|null
     */
    protected ?string $trueLabel;

    /**
     * The link for a value that is true.
     * Default: null.
     *
     * @var string|null
     */
    protected ?string $trueLabelRoute;

    /**
     * @var Closure|array|null
     */
    protected Closure|array|null $trueLabelRouteParameters;

    /**
     * The label for a value that is false.
     * Default: null.
     *
     * @var string|null
     */
    protected ?string $falseLabel;

    //-------------------------------------------------
    // ColumnInterface
    //-------------------------------------------------

    /**
     * {@inheritdoc}
     */
    public function renderSingleField(array &$row): static
    {
        $path = Helper::getDataPropertyPath($this->data);

        if ($this->accessor->isReadable($row, $path)) {
            if (true === $this->isEditableContentRequired($row)) {
                $content = $this->renderTemplate($this->accessor->getValue($row, $path), $row[$this->editable->getPk()]);
            } else {
                $content = $this->renderTemplate($this->accessor->getValue($row, $path), null, null, $row);
            }

            $this->accessor->setValue($row, $path, $content);
        }

        return $this;
    }

    /**
     * {@inheritdoc}
     */
    public function renderToMany(array &$row): static
    {
        $value = null;
        $path = Helper::getDataPropertyPath($this->data, $value);

        if ($this->accessor->isReadable($row, $path)) {
            $entries = $this->accessor->getValue($row, $path);

            if (\count($entries) > 0) {
                foreach ($entries as $key => $entry) {
                    $currentPath = $path.'['.$key.']'.$value;
                    $currentObjectPath = Helper::getPropertyPathObjectNotation($path, $key, $value);

                    if (true === $this->isEditableContentRequired($row)) {
                        $content = $this->renderTemplate(
                            $this->accessor->getValue($row, $currentPath),
                            $row[$this->editable->getPk()],
                            $currentObjectPath
                        );
                    } else {
                        $content = $this->renderTemplate($this->accessor->getValue($row, $currentPath));
                    }

                    $this->accessor->setValue($row, $currentPath, $content);
                }
            }
            // no placeholder - leave this blank
        }

        return $this;
    }

    /**
     * {@inheritdoc}
     */
    public function getCellContentTemplate(): string
    {
        return 'bundles\SgDatatablesBundle\render\booleanWithLink.html.twig';
    }

    /**
     * {@inheritdoc}
     */
    public function renderPostCreateDatatableJsContent(): ?string
    {
        if ($this->editable instanceof EditableInterface) {
            return $this->twig->render(
                '@SgDatatables/column/column_post_create_dt.js.twig',
                [
                    'column_class_editable_selector' => $this->getColumnClassEditableSelector(),
                    'editable_options' => $this->editable,
                    'entity_class_name' => $this->getEntityClassName(),
                    'column_dql' => $this->dql,
                    'original_type_of_field' => $this->getOriginalTypeOfField(),
                ]
            );
        }

        return null;
    }

    //-------------------------------------------------
    // Options
    //-------------------------------------------------

    /**
     * @return $this
     */
    public function configureOptions(OptionsResolver $resolver): static
    {
        parent::configureOptions($resolver);

        $resolver->setDefaults(
            [
                'filter' => [
                    SelectFilter::class,
                    [
                        'search_type' => 'eq',
                        'select_options' => ['' => 'Any', '1' => 'Yes', '0' => 'No'],
                    ],
                ],
                'true_icon' => null,
                'false_icon' => null,
                'true_label' => null,
                'true_label_route' => null,
                'true_label_route_parameters' => null,
                'false_label' => null,
                'editable' => null,
            ]
        );

        $resolver->setAllowedTypes('filter', 'array');
        $resolver->setAllowedTypes('true_icon', ['null', 'string']);
        $resolver->setAllowedTypes('false_icon', ['null', 'string']);
        $resolver->setAllowedTypes('true_label', ['null', 'string']);
        $resolver->setAllowedTypes('true_label_route', ['null', 'string']);
        $resolver->setAllowedTypes('true_label_route_parameters', ['null', 'array', 'Closure']);
        $resolver->setAllowedTypes('false_label', ['null', 'string']);
        $resolver->setAllowedTypes('editable', ['null', 'array']);

        $resolver->setNormalizer('true_label', function (Options $options, $value) {
            if (null === $options['true_icon'] && null === $value) {
                $value = self::RENDER_TRUE_VALUE;
            }

            return $value;
        });

        $resolver->setNormalizer('false_label', function (Options $options, $value) {
            if (null === $options['false_icon'] && null === $value) {
                $value = self::RENDER_FALSE_VALUE;
            }

            return $value;
        });

        return $this;
    }

    //-------------------------------------------------
    // Getters && Setters
    //-------------------------------------------------

    /**
     * @return string|null
     */
    public function getTrueIcon(): ?string
    {
        return $this->trueIcon;
    }

    /**
     * @param string|null $trueIcon
     *
     * @return $this
     */
    public function setTrueIcon(?string $trueIcon): static
    {
        $this->trueIcon = $trueIcon;

        return $this;
    }

    /**
     * @return string|null
     */
    public function getTrueLabelRoute(): ?string
    {
        return $this->trueLabelRoute;
    }

    public function setTrueLabelRoute(?string $trueLabelRoute): static
    {
        $this->trueLabelRoute = $trueLabelRoute;

        return $this;
    }

    /**
     * @return Closure|array|null
     */
    public function getTrueLabelRouteParameters(): \Closure|array|null
    {
        return $this->trueLabelRouteParameters;
    }

    /**
     * @param \Closure|array|null $trueLabelRouteParameters
     */
    public function setTrueLabelRouteParameters(\Closure|array|null $trueLabelRouteParameters): void
    {
        $this->trueLabelRouteParameters = $trueLabelRouteParameters;
    }

    /**
     * @return string|null
     */
    public function getFalseIcon(): ?string
    {
        return $this->falseIcon;
    }

    /**
     * @param string|null $falseIcon
     *
     * @return $this
     */
    public function setFalseIcon(?string $falseIcon): static
    {
        $this->falseIcon = $falseIcon;

        return $this;
    }

    /**
     * @return string|null
     */
    public function getTrueLabel(): ?string
    {
        return $this->trueLabel;
    }

    /**
     * @param string|null $trueLabel
     *
     * @return $this
     */
    public function setTrueLabel(?string $trueLabel): static
    {
        $this->trueLabel = $trueLabel;

        return $this;
    }

    /**
     * @return string|null
     */
    public function getFalseLabel(): ?string
    {
        return $this->falseLabel;
    }

    /**
     * @param string|null $falseLabel
     *
     * @return $this
     */
    public function setFalseLabel(?string $falseLabel): static
    {
        $this->falseLabel = $falseLabel;

        return $this;
    }

    //-------------------------------------------------
    // Helper
    //-------------------------------------------------

    /**
     * Render template.
     *
     * @param string|null $data
     * @param string|null $pk
     * @param string|null $path
     *
     * @return mixed|string
     */
    private function renderTemplate($data, $pk = null, $path = null, $row = null)
    {
        /*var_dump($this->trueLabel,$data);
        var_dump(\in_array($data, [0, 1, '0', '1'], true));
        var_dump($this->isCustomDql() && \in_array($data, [0, 1, '0', '1'], true) ? (bool) $data : $data);
        */

        $parameters = [];
        //Process route params and if is id than assign table row id
        $rowId = $row['id'];
        if(is_array($this->trueLabelRouteParameters)){
            foreach ($this->trueLabelRouteParameters as $key => $parameter) {
                if($parameter === 'id'){
                    $parameters[$key] = $rowId;
                }else{
                    $parameters[$key] = $parameter;
                }
            }
        }

        $renderVars = [
            'data' => $this->isCustomDql() && \in_array($data, [0, 1, '0', '1'], true) ? (bool) $data : (bool) $data,
            'default_content' => $this->getDefaultContent(),
            'true_label' => $this->trueLabel,
            'true_label_route' => $this->trueLabelRoute,
            'true_label_route_parameters' => $parameters,
            'true_icon' => $this->trueIcon,
            'false_label' => $this->falseLabel,
            'false_icon' => $this->falseIcon,
        ];

        // editable vars
        if (null !== $pk) {
            $renderVars = array_merge($renderVars, [
                'column_class_editable_selector' => $this->getColumnClassEditableSelector(),
                'pk' => $pk,
                'path' => $path,
                'empty_text' => $this->editable->getEmptyText(),
            ]);
        }

        return $this->twig->render(
            $this->getCellContentTemplate(),
            $renderVars
        );
    }
}
